TITLE '1x2 cells, planar flow, radial inner geometry, 2 laminae'
COORDINATES cartesian2
SELECT
errlim=1e-7
VARIABLES
p
DEFINITIONS
mesh_density=2
#include "const_read.pde"
#include "input_read.pde"

Kp
Cp
r_outx=r_B
r_outy=r_B
gflag=0
grav=gflag*vector(0,-g,0)
xr_length=0
xl_length=0
yr_length=0
yl_length=0
alpha=arctan(r_outy/r_outx)
dalpha=alpha/2

pX=p_atm
pX2=pX^2
muRTCx=muRTC/pX^2
muRTCpx=muRT*Cp/pX^2

u=-Kp/mu_lfg*dx(p)*pX
v=-Kp/mu_lfg*(dy(p)+gflag*g*p/RT)*pX
rho=p/RT*pX
flux_x=u*rho*dl
flux_y=v*rho*dl

p_frac=0.5

INITIAL VALUES
p=p_atm/pX
EQUATIONS
div(Kp*p*(grad(p)-p/RT*grav))=-muRTCpx

BOUNDARIES
REGION 'AC'
Kp=k[2]
Cp=C

start 'rec' (2*r_outx,-r_outy)
natural(p)=0
line to (2*r_outx,r_outy)
!value(p)=pB/pX
natural(p)=0
line to (-2*r_outx,r_outy)
natural(p)=0
line to (-2*r_outx,-r_outy)
natural(p)=0
line to close

start (r_P-r_outx,0)
value(p)=p_out/pX+(1-p_out/pX)*p_frac
arc(center=-r_outx,0) angle=360
start (r_P+r_outx,0)
value(p)=p_out/pX 
arc(center=r_outx,0) angle=360

REGION 'AB'
Kp=k[1]
Cp=0
start (r_A-r_outx,0)
arc(center=-r_outx,0) angle=360
start (r_P-r_outx,0)
arc(center=-r_outx,0) angle=360
start (r_A+r_outx,0)
arc(center=r_outx,0) angle=360
start (r_P+r_outx,0)
arc(center=r_outx,0) angle=360

! rays
repeat th = 0 by dalpha to alpha
Feature 'rayr_'+$th
xr_length=if(cos(th)=0) then 0
          else if (th<=alpha) then r_outx
          else r_outy*cos(th)/sin(th)
yr_length=if(th<alpha) then r_outx*tan(th)
          else r_outy
start(r_P*cos(th)+r_outx,r_P*sin(th)) 
 line to (xr_length+r_outx, yr_length)
endrepeat
 
repeat th = 0 by dalpha to alpha
Feature 'rayl_'+$th
xl_length=if(cos(th)=0) then 0
          else if (th<=alpha) then r_outx
          else r_outy*cos(th)/sin(th)
yl_length=if(th<alpha) then r_outx*tan(th)
         else r_outy
start(r_P*cos(th)-r_outx,r_P*sin(th)) 
 line to (xl_length-r_outx, yl_length)
endrepeat

Feature 'cline'
start (0,-r_outy) 
line to (0,r_outy)

PLOTS
!Contour(p) PAINTED
Elevation(p) on 'cline' 
  export points=100 
  file='c1x2p_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
Elevation(flux_x) on 'cline' 
  export points=100 
  file='c1x2u_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
repeat th = 0 by dalpha to alpha
  Elevation(p) on 'rayr_'+$th 
  Elevation(p) on 'rayl_'+$th 
endrepeat
summary
  report(mu_lfg) as "lfg viscosity"
  report(Rlfg) as "lfg gas constant"
  report(line_integral(flux_x,'cline')) as "h flux across central line"
END
