Title '1x3 cells, planar flow, radial inner geometry, 2 laminae'
Coordinates cartesian2
Select
errlim=1e-7
Variables
p
Definitions
mesh_density=2
#include "const_read.pde"
#include "input_read.pde"

Kp
Cp
r_outx=r_B
r_outy=r_B
gflag=0
grav=gflag*vector(0,-g,0)
xr_length=0
xl_length=0
yr_length=0
yl_length=0
alpha=arctan(r_outy/r_outx)
dalpha=alpha/2

pX=p_atm
pX2=pX^2
muRTCx=muRTC/pX^2
muRTCpx=muRT*Cp/pX^2

u=-Kp/mu_lfg*dx(p)*pX
v=-Kp/mu_lfg*(dy(p)+gflag*g*p/RT)*pX
rho=p/RT*pX
flux_x=u*rho*dl
flux_y=v*rho*dl

p_frac=0.6

Initial values
p=p_atm/pX
Equations
div(Kp*p*(grad(p)-p/RT*grav))=-muRTCpx

Boundaries
Region 'AC'
Kp=k[2]
Cp=C

start 'rec' (3*r_outx,-r_outy)
natural(p)=0
line to (3*r_outx,r_outy)
value(p)=pB/pX
!natural(p)=0
line to (-3*r_outx,r_outy)
natural(p)=0
line to (-3*r_outx,-r_outy)
natural(p)=0
line to close

start (r_P,0)
value(p)=p_out/pX
arc(center=0,0) angle=360
start (r_P-2*r_outx,0)
value(p)=p_out/pX+(1-p_out/pX)*max(p_frac,0)
arc(center=-2*r_outx,0) angle=360
start (r_P+2*r_outx,0)
value(p)=p_out/pX-(1-p_out/pX)*min(p_frac,0)
arc(center=2*r_outx,0) angle=360

Region 'AB'
Kp=k[1]
Cp=0
start (r_A,0)
arc(center=0,0) angle=360
start (r_P,0)
arc(center=0,0) angle=360
start (r_A-2*r_outx,0)
arc(center=-2*r_outx,0) angle=360
start (r_P-2*r_outx,0)
arc(center=-2*r_outx,0) angle=360
start (r_A+2*r_outx,0)
arc(center=2*r_outx,0) angle=360
start (r_P+2*r_outx,0)
arc(center=2*r_outx,0) angle=360

! rays
repeat th = 0 by dalpha to alpha
Feature 'rayc_'+$th
xr_length=if(cos(th)=0) then 0
          else if (th<=alpha) then r_outx
          else r_outy*cos(th)/sin(th)
yr_length=if(th<alpha) then r_outx*tan(th)
          else r_outy
start(r_P*cos(th),r_P*sin(th))
 line to (xr_length, yr_length)
endrepeat

repeat th = 0 by dalpha to alpha
Feature 'rayr_'+$th
xr_length=if(cos(th)=0) then 0
          else if (th<=alpha) then r_outx
          else r_outy*cos(th)/sin(th)
yr_length=if(th<alpha) then r_outx*tan(th)
          else r_outy
start(r_P*cos(th)+2*r_outx,r_P*sin(th)) 
 line to (xr_length+2*r_outx, yr_length)
endrepeat
 
repeat th = 0 by dalpha to alpha
Feature 'rayl_'+$th
xl_length=if(cos(th)=0) then 0
          else if (th<=alpha) then r_outx
          else r_outy*cos(th)/sin(th)
yl_length=if(th<alpha) then r_outx*tan(th)
         else r_outy
start(r_P*cos(th)-2*r_outx,r_P*sin(th)) 
 line to (xl_length-2*r_outx, yl_length)
endrepeat

Feature 'rline'
start (r_outx,-r_outy) 
line to (r_outx,r_outy)
Feature 'lline'
start (-r_outx,-r_outy) 
line to (-r_outx,r_outy)

Feature 'cpipe'
start (r_P,0)
arc(center=0,0) angle=360
Feature 'lpipe'
start (r_P-2*r_outx,0)
arc(center=-2*r_outx,0) angle=360
Feature 'rpipe'
start (r_P+2*r_outx,0)
arc(center=2*r_outx,0) angle=360

PLOTS
!Contour(p) Painted
Elevation(p) on 'lline' 
Elevation(p) on 'rline' 
!  export points=100 
!  file='c1x2p_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
Elevation(flux_x) on 'lline' 
Elevation(flux_x) on 'rline' 
!  export points=100 
!  file='c1x2u_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
repeat th = 0 by dalpha to alpha
  Elevation(p) on 'rayc_'+$th 
  Elevation(p) on 'rayl_'+$th 
  Elevation(p) on 'rayr_'+$th 
endrepeat
Elevation(p) on 'cpipe'
Elevation(p) on 'lpipe'
Elevation(p) on 'rpipe'
summary
  report(mu_lfg) as "lfg viscosity"
  report(Rlfg) as "lfg gas constant"
  report(line_integral(flux_x,'lline')) as "h flux across left line"
  report(line_integral(flux_x,'rline')) as "h flux across right line"
END
