TITLE '2x1 cells, planar flow, radial inner geometry, 2 laminae'
COORDINATES cartesian2
SELECT
errlim=1e-7
VARIABLES
p
DEFINITIONS
mesh_density=1
#include "const_read.pde"
#include "input_read.pde"

Kp
Cp
r_outx=r_B
r_outy=r_B
gflag=0
grav=gflag*vector(0,-g,0)
xt_length=0
xb_length=0
yt_length=0
yb_length=0
alpha=arctan(r_outy/r_outx)
dalpha=alpha/2

pX=p_atm
pX2=pX^2
muRTCx=muRTC/pX^2
muRTCpx=muRT*Cp/pX^2

u=-Kp/mu_lfg*dx(p)*pX
v=-Kp/mu_lfg*(dy(p)+gflag*g*p/RT)*pX
rho=p/RT*pX
flux_x=u*rho*dl
flux_y=v*rho*dl

p_frac=-1;

INITIAL VALUES
p=p_atm/pX
EQUATIONS
div(Kp*p*(grad(p)-p/RT*grav))=-muRTCpx

BOUNDARIES
REGION 'AC'
Kp=k[2]
Cp=C

start 'rec' (r_outx,-2*r_outy)
natural(p)=0
line to (r_outx,2*r_outy)
value(p)=pB/pX
!natural(p)=0
line to (-r_outx,2*r_outy)
natural(p)=0
line to (-r_outx,-2*r_outy)
natural(p)=0
line to close

{
start (r_P,-r_outy)
!value(p)=p_out/pX ! p_frac<0
value(p)=p_out/pX+(1-p_out/pX)*p_frac ! p_frac>0
arc(center=0,-r_outy) angle=360
start (r_P,r_outy)
!value(p)=p_out/pX-(1-p_out/pX)*p_frac ! p_frac<0
value(p)=p_out/pX ! p_frac>0
arc(center=0,r_outy) angle=360
}

start (r_P,-r_outy)
value(p)=if p_frac<0 then p_out/pX else p_out/pX+(1-p_out/pX)*p_frac
arc(center=0,-r_outy) angle=360
start (r_P,r_outy)
value(p)=if p_frac>0 then p_out/pX else p_out/pX-(1-p_out/pX)*p_frac
arc(center=0,r_outy) angle=360

REGION 'AB'
Kp=k[1]
Cp=0
start (r_A,-r_outy)
arc(center=0,-r_outy) angle=360
start (r_P,-r_outy)
arc(center=0,-r_outy) angle=360
start (r_A,+r_outy)
arc(center=0,+r_outy) angle=360
start (r_P,+r_outy)
arc(center=0,+r_outy) angle=360

! rays
repeat th = 0 by dalpha to alpha
Feature 'rayr_'+$th
xt_length=if(cos(th)=0) then 0
          else if (th<=alpha) then r_outx
          else r_outy*cos(th)/sin(th)
yt_length=if(th<alpha) then r_outx*tan(th)
          else r_outy
start(r_P*cos(th),r_P*sin(th)+r_outy) 
 line to (xt_length,yt_length+r_outy)
endrepeat
 
repeat th = 0 by dalpha to alpha
Feature 'rayl_'+$th
xb_length=if(cos(th)=0) then 0
          else if (th<=alpha) then r_outx
          else r_outy*cos(th)/sin(th)
yb_length=if(th<alpha) then r_outx*tan(th)
         else r_outy
start(r_P*cos(th),r_P*sin(th)-r_outy) 
 line to (xb_length,yb_length-r_outy)
endrepeat

Feature 'cline'
start (-r_outx,0)
line to (r_outx,0)

PLOTS
!Contour(p) PAINTED
Elevation(p) on 'cline'
!  export points=100
!  file='c1x2p_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
Elevation(flux_y) on 'cline'
!  export points=100
!  file='c1x2u_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
repeat th = 0 by dalpha to alpha
   Elevation(p) on 'rayr_'+$th 
   Elevation(p) on 'rayl_'+$th 
endrepeat
summary
  report(mu_lfg) as "lfg viscosity"
  report(Rlfg) as "lfg gas constant"
  report(line_integral(flux_y,'cline')) as "h flux across central line"
END
