TITLE '2x1 cells, planar flow, radial inner geometry, 2 laminae'
COORDINATES cartesian2
SELECT
errlim=1e-7
VARIABLES
p
DEFINITIONS
mesh_density=2
#include "const_read.pde"
#include "input_read.pde"

Kp
Cp
r_outx=r_B
r_outy=r_B
gflag=1
grav=gflag*vector(0,-g,0)
xtl_length=0
ytl_length=0
xbl_length=0
ybl_length=0
xtr_length=0
ytr_length=0
xbr_length=0
ybr_length=0
alpha=arctan(r_outy/r_outx)
dalpha=alpha/2

pX=p_atm
pX2=pX^2
muRTCx=muRTC/pX^2
muRTCpx=muRT*Cp/pX^2

u=-Kp/mu_lfg*dx(p)*pX
v=-Kp/mu_lfg*(dy(p)+gflag*g*p/RT)*pX
rho=p/RT*pX
flux_x=u*rho*dl
flux_y=v*rho*dl

p_frac=1;

INITIAL VALUES
p=p_atm/pX
EQUATIONS
div(Kp*p*(grad(p)-p/RT*grav))=-muRTCpx

BOUNDARIES
REGION 'AC'
Kp=k[2]
Cp=C

start 'rec' (2*r_outx,-2*r_outy)
natural(p)=0
line to (2*r_outx,2*r_outy)
!value(p)=pB/pX
natural(p)=0
line to (-2*r_outx,2*r_outy)
natural(p)=0
line to (-2*r_outx,-2*r_outy)
natural(p)=0
line to close

start (r_P+r_outx,-r_outy) {bottom right}
value(p)=p_out/pX
arc(center=r_outx,-r_outy) angle=360
start (r_P+r_outx,r_outy) {top right}
value(p)=p_out/pX
arc(center=r_outx,r_outy) angle=360
start (r_P-r_outx,-r_outy) {bottom left}
value(p)=p_out/pX+(1-p_out/pX)*max(p_frac,0)
arc(center=-r_outx,-r_outy) angle=360
start (r_P-r_outx,r_outy) {top left}
value(p)=p_out/pX-(1-p_out/pX)*min(p_frac,0)
arc(center=-r_outx,r_outy) angle=360

REGION 'AB'
Kp=k[1]
Cp=0
start (r_A+r_outx,-r_outy)
arc(center=r_outx,-r_outy) angle=360
start (r_P+r_outx,-r_outy)
arc(center=r_outx,-r_outy) angle=360
start (r_A+r_outx,+r_outy)
arc(center=r_outx,+r_outy) angle=360
start (r_P+r_outx,+r_outy)
arc(center=r_outx,+r_outy) angle=360
start (r_A-r_outx,-r_outy)
arc(center=-r_outx,-r_outy) angle=360
start (r_P-r_outx,-r_outy)
arc(center=-r_outx,-r_outy) angle=360
start (r_A-r_outx,+r_outy)
arc(center=-r_outx,+r_outy) angle=360
start (r_P-r_outx,+r_outy)
arc(center=-r_outx,+r_outy) angle=360

! rays
repeat th = 0 by dalpha to alpha
Feature 'raytl_'+$th
xtl_length=if(cos(th)=0) then 0
           else if (th<=alpha) then r_outx
           else r_outy*cos(th)/sin(th)
ytl_length=if(th<alpha) then r_outx*tan(th)
           else r_outy
start(r_P*cos(th)-r_outx,r_P*sin(th)+r_outy) 
 line to (xtl_length-r_outx,ytl_length+r_outy)
endrepeat
 
repeat th = 0 by dalpha to alpha
Feature 'raybl_'+$th
xbl_length=if(cos(th)=0) then 0
           else if (th<=alpha) then r_outx
           else r_outy*cos(th)/sin(th)
ybl_length=if(th<alpha) then r_outx*tan(th)
           else r_outy
start(r_P*cos(th)-r_outx,r_P*sin(th)-r_outy) 
 line to (xbl_length-r_outx,ybl_length-r_outy)
endrepeat

repeat th = 0 by dalpha to alpha
Feature 'raytr_'+$th
xtr_length=if(cos(th)=0) then 0
           else if (th<=alpha) then r_outx
           else r_outy*cos(th)/sin(th)
ytr_length=if(th<alpha) then r_outx*tan(th)
           else r_outy
start(r_P*cos(th)+r_outx,r_P*sin(th)+r_outy)
 line to (xtr_length+r_outx,ytr_length+r_outy)
endrepeat
 
repeat th = 0 by dalpha to alpha
Feature 'raybr_'+$th
xbr_length=if(cos(th)=0) then 0
           else if (th<=alpha) then r_outx
           else r_outy*cos(th)/sin(th)
ybr_length=if(th<alpha) then r_outx*tan(th)
           else r_outy
start(r_P*cos(th)+r_outx,r_P*sin(th)-r_outy)
 line to (xbr_length+r_outx,ybr_length-r_outy)
endrepeat

Feature 'lline'
start (-2*r_outx,0) line to (0,0)
Feature 'rline'
start (0,0) line to (2*r_outx,0)
Feature 'bline'
start (0,-2*r_outy) line to (0,0)
Feature 'tline'
start (0,0) line to (0,2*r_outy)

PLOTS
Contour(sqrt(u^2+v^2)) PAINTED
!Elevation(p) on 'lline'
!Elevation(p) on 'rline'
!Elevation(p) on 'bline'
!Elevation(p) on 'tline'
!  export points=100
!  file='c1x2p_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
!Elevation(flux_y) on 'lline'
!Elevation(flux_y) on 'rline'
!Elevation(flux_x) on 'bline'
!Elevation(flux_x) on 'tline'
!  export points=100
!  file='c1x2u_f'+$round(p_frac*10)+'_'+$(r_outx/r_outy)+'X.tbl'
!repeat th = 0 by dalpha to alpha
!   Elevation(p) on 'raytr_'+$th 
!   Elevation(p) on 'raytl_'+$th 
!   Elevation(p) on 'raybr_'+$th 
!   Elevation(p) on 'raybl_'+$th 
!endrepeat
summary
  report(mu_lfg) as "lfg viscosity"
  report(Rlfg) as "lfg gas constant"
  report(line_integral(flux_y,'lline')) as "h flux across left line"
  report(line_integral(flux_y,'rline')) as "h flux across right line"
  report(line_integral(flux_x,'bline')) as "h flux across bottom line"
  report(line_integral(flux_x,'tline')) as "h flux across top line"
END
